@@ -1,4 +1,4 @@
-from http import HTTPStatus
+
 
 from .base import APIEndpoint
 from dhlparcel.models.base import ObjectListModel
@@ -24,6 +24,6 @@ class PickupAvailabilityMethods(APIEndpoint):
         }
         
         status, headers, resp_json = self.api.get(self.endpoint, data)
-        if status != HTTPStatus.OK: return ObjectListModel().set_error(returned_content=resp_json, status=status)
+        if status > 399: return ObjectListModel().set_error(returned_content=resp_json, status=status)
         
         return ObjectListModel().construct_from_response(resp_json)
\ No newline at end of file
